sublime-harness changelog
=========================
0.3.0 - Fixed up environment variable and tests for Vagrant

0.2.0 - Updated run order of tests for faster feedback loops against Travis CI

0.1.1 - Corrected invalid headings in README

0.1.0 - Initial release
